### Financial portfolio optimization with amplpy

This package replicates financial portfolio optimization models 
from [PyPortfolioOpt/pypfopt](https://github.com/robertmartin8/PyPortfolioOpt) using [amplpy](https://github.com/ampl/amplpy).

#### Repositories

- GitHub Repository: https://github.com/ampl/amplpy/tree/master/amplpyfinance
- PyPI Repository: https://pypi.python.org/pypi/amplpyfinance
- PyPortfolioOpt Repository: https://github.com/robertmartin8/PyPortfolioOpt

#### Setup

Install from the [repository](https://pypi.python.org/pypi/amplpyfinance):
```
$ python -m pip install amplpyfinance
```

#### License

MIT

***
Copyright © 2022-2022 AMPL Optimization inc. All rights reserved.
